#
# Label Support Class
# (C) Copyright 2001 bluedynamics.com
# All Rights Reserved
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#  1. Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#  2. Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# Author: Stephan Richter <srichter@iuveno-net.de>

from Globals import HTMLFile
import string

class LabelSupport:
    '''LabelSupport class - '''

    manage_options = ({'label': 'Labels',   'action': 'manage_labels'},)

    sqlMethods = ( ('qry_getLabelLanguages', '', ''),
                   ('qry_getLabels',         '', ''),
                   ('sql_deleteLanguage',    '', 'lang:string:required'),
                   ('sql_updateLabel',       '', 'lang:string:required phrase_id:int:required text:string=""'),
                   ('sql_deleteLabel',       '', 'phrase_id:int:required'),
                   )

    manage_labels = HTMLFile('manage_labels', globals())


    def manage_changeEditLanguages(self, REQUEST):
        ''' '''
        if not REQUEST.form.has_key('langs'):
            REQUEST.form['langs'] = []
            
        REQUEST['RESPONSE'].setCookie('langs', string.join(REQUEST.form['langs'], ','))
        REQUEST.cookies['langs'] = string.join(REQUEST.form['langs'], ',')

        if REQUEST:
            return self.manage_labels(self, REQUEST)


    def getEditLanguages(self, REQUEST):
        ''' '''
        if REQUEST.cookies.has_key('langs'):
            return string.split(REQUEST.cookies['langs'], ',')
        else:
            return []


    def manage_addLabelLanguage(self, REQUEST):
        ''' '''
        lang = string.strip(REQUEST['lang'])
        for label in self.qry_getLabels():
            self.sql_newPhrase(lang=lang, md5Hash=label.md5hash, renderPath=label.renderpath,
                               renderText=label.rendertext)

        if REQUEST:
            return self.manage_labels(self, REQUEST)


    def manage_deleteLabelLanguages(self, REQUEST):
        ''' '''
        editLangs = self.getEditLanguages(REQUEST)
        for lang in REQUEST.form['langs']:
            self.sql_deleteLanguage(lang=lang)
            if lang in editLangs:
                editLangs.remove(lang)

        REQUEST.form['langs'] = editLangs
        return self.manage_changeEditLanguages(REQUEST)


    def manage_addLabels(self, REQUEST):
        ''' '''
        path = self.absolute_url()
        hashDict = {}
        for key in REQUEST.form.keys():
            if key[:3] == 'new' and key[4:9] == 'label':
                hashDict[string.split(key, '-')[-1]] = self._makeDigest(REQUEST.form[key])

        for key in REQUEST.form.keys():
            if key[:3] == 'new' and REQUEST.form[key]:
                garbage, lang, number = string.split(key, '-')
                if number in hashDict.keys():
                    self.sql_newPhrase(lang = lang, md5Hash = hashDict[number], renderPath = path,
                                       renderText = REQUEST.form[key])

        if REQUEST:
            return self.manage_labels(self, REQUEST)
            

    def manage_updateLabels(self, REQUEST):
        ''' '''
        for key in REQUEST.form.keys():
            if key[:2] == 'p-':
                garbage, lang, phrase_id = string.split(key, '-')
                self.sql_updateLabel(lang = lang, phrase_id = phrase_id, text = REQUEST.form[key])

        self.manage_addLabels(REQUEST)

        if REQUEST:
            return self.manage_labels(self, REQUEST)


    def manage_deleteLabels(self, REQUEST):
        ''' '''
        if REQUEST.form.has_key('labelIds'):
            for id in REQUEST.form['labelIds']:
                self.sql_deleteLabel(phrase_id=id)
                
        if REQUEST:
            return self.manage_labels(self, REQUEST)
